/**
 * Select a purchasing process status
 *
 * @module package/quiqqer/purchasing/bin/js/backend/controls/settings/OrderStatusSelect
 * @author www.pcsg.de (Patrick Müller)
 *
 * @event onChange [value, this]
 * @event onLoaded [this] - Fires if all statusses have been loaded
 */
define('package/quiqqer/user-downloads/bin/js/backend/controls/settings/OrderStatusSelect', [

    'qui/controls/Control',
    'qui/controls/loader/Loader',

    'Locale',
    'Packages',

    'css!package/quiqqer/user-downloads/bin/js/backend/controls/settings/OrderStatusSelect.css'

], function(QUIControl, QUILoader, QUILocale, Packages) {
    'use strict';

    const lg = 'quiqqer/user-downloads';

    return new Class({
        Extends: QUIControl,
        Type: 'package/quiqqer/purchasing/bin/js/backend/controls/settings/OrderStatusSelect',

        Binds: [
            '$onImport',
            '$setValue',
            '$onInject',
            'setValue'
        ],

        options: {
            showIcons: false,
            placeholderText: false,
            placeholderSelectable: false
        },

        initialize: function(options) {
            this.parent(options);

            this.$Elm = null;
            this.Loader = new QUILoader();

            this.$fireEvents = true;

            this.addEvents({
                onInject: this.$onInject,
                onImport: this.$onImport
            });
        },

        /**
         * create the domnode element
         */
        create: function() {
            this.$Elm = new Element('div', {
                'class': 'quiqqer-user-downloads-OrderStatusSelect field-container-field'
            });

            this.Loader.inject(this.$Elm);

            return this.$Elm;
        },

        /**
         * event: on inject
         */
        $onInject: function() {
            const self = this;

            this.Loader.show();

            Packages.isInstalled('quiqqer/order').then(function(isInstalled) {
                if (!isInstalled) {
                    new Element('div', {
                        html: QUILocale.get(lg, 'controls.OrderStatusSelect.quiqqer_order_not_installed')
                    }).inject(self.$Elm);

                    self.Loader.hide();
                    return;
                }

                require(['package/quiqqer/order/bin/backend/utils/StatusSelect'], function(OrderStatusSelect) {
                    new OrderStatusSelect().imports(self.$Input);
                    self.Loader.hide();
                });
            });
        },

        /**
         * event: on import
         */
        $onImport: function() {
            if (this.$Elm.nodeName === 'INPUT') {
                this.$Input = this.$Elm;
                this.$Input.type = 'hidden';
            }

            if (this.$Elm.nodeName === 'SELECT') {
                this.$Input = this.$Elm;
                this.$Input.setStyle('display', 'none');
            }

            this.create().wraps(this.$Input);
            this.$onInject();
        },

        /**
         * Set current value to input
         * @param statusId
         */
        setValue: function(statusId) {
            this.$Input.value = statusId;

            this.$fireEvents = false;
            this.$Select.setValue(statusId);
            this.$fireEvents = true;
        }
    });
});