/**
 * Display user downloads manager in user panel
 *
 * @module package/quiqqer/user-downloads/bin/js/backend/controls/users/UserDownloadsCategory
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/user-downloads/bin/js/backend/controls/users/UserDownloadsCategory', [

    'qui/controls/Control',
    'utils/Controls',

    'package/quiqqer/user-downloads/bin/js/backend/controls/users/UserDownloads',

    'css!package/quiqqer/user-downloads/bin/js/backend/controls/users/UserDownloadsCategory.css'

], function(QUIControl, QUIControlUtils, UserDownloadsManager) {
    'use strict';

    return new Class({

        Extends: QUIControl,
        Type: 'package/quiqqer/user-downloads/bin/js/backend/controls/users/UserDownloadsCategory',

        Binds: [
            '$onInject',
            '$onResize'
        ],

        initialize: function(options) {
            this.parent(options);

            this.$Manager = null;

            this.addEvents({
                onInject: this.$onInject,
                onImport: this.$onImport
            });
        },

        /**
         * Event: onResize
         */
        $onResize: function() {
            if (this.$Manager) {
                this.$Manager.resize();
            }
        },

        /**
         * Event: onImport
         */
        $onImport: function() {
            const Input = this.getElm();
            const Table = Input.getParent('table');

            this.$Elm = new Element('div', {
                'class': 'quiqqer-user-downloads-container'
            }).inject(Table, 'before');

            Table.destroy();

            this.$onInject();
        },

        /**
         * Event: onInject
         */
        $onInject: function() {
            const self = this;

            // if control is injected in a panel, register onResize event
            QUIControlUtils.getControlByElement(
                this.$Elm.getParent('.qui-panel')
            ).then(function(Panel) {

                Panel.addEvent('onResize', self.$onResize);

                let userId;

                switch (Panel.getType()) {
                    case 'package/quiqqer/customer/bin/backend/controls/customer/Panel':
                        userId = Panel.getAttribute('userId');
                        //
                        //const Form = self.$Elm.getParent('form');
                        //
                        //Form.setStyle('height', '100%');
                        break;

                    default:
                        userId = Panel.getUser().getId();
                }

                self.$Manager = new UserDownloadsManager({
                    userId: userId
                }).inject(self.$Elm);
            }, function() {
                // do nothing if no panel found
            });

            this.$Elm.getParent('form').setStyles({
                float: 'left',
                height: '100%',
                width: '100%'
            });

            this.$Elm.addClass('quiqqer-payments-user-paymentsrestrictions');
        }
    });
});
